
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Users, Calendar, Target, Kanban, FileText, TrendingUp, Shield, Brain, Globe } from "lucide-react";
import { Link } from "react-router-dom";
import Header from "@/components/Header";
import Footer from "@/components/Footer";
import SEO from "@/components/SEO";

const Features = () => {
  const structuredData = {
    "@context": "https://schema.org",
    "@type": "WebPage",
    "name": "Workplaze Features - Complete Professional Services Management",
    "description": "Comprehensive feature set including HRMS, CRM, Project Management, Resource Planning, and Performance Management for digital agencies.",
    "mainEntity": {
      "@type": "SoftwareApplication",
      "name": "Workplaze",
      "featureList": [
        "Human Resource Management System",
        "Customer Relationship Management",
        "Project Management with Kanban",
        "Resource Planning & Utilization",
        "Performance Management",
        "Financial Administration"
      ]
    }
  };

  const features = [
    {
      icon: Users,
      title: "Human Resource Management System (HRMS)",
      subtitle: "Streamline HR Operations & Empower Your Team",
      description: "Efficiently track employee attendance, maintain and assess skills and competencies, and manage centralized employee records and their lifecycle from onboarding to offboarding.",
      keywords: ["HRMS", "attendance management", "skill management", "employee lifecycle"]
    },
    {
      icon: Target,
      title: "Customer Relationship Management (CRM)",
      subtitle: "Close More Deals with Integrated CRM",
      description: "Visualize and manage your sales opportunities with intuitive pipeline and Kanban boards. Store and manage all your client and contact information in one place.",
      keywords: ["CRM", "opportunity pipeline", "sales management", "client management"]
    },
    {
      icon: TrendingUp,
      title: "Resource Planning",
      subtitle: "Optimize Your Workforce & Maximize Utilization",
      description: "Monitor resource allocation with utilization reports, accurately forecast future resource needs based on project pipelines, and assign resources to projects for optimal utilization. Manage external consultants seamlessly.",
      keywords: ["Resource management", "utilization reports", "resource forecasting"]
    },
    {
      icon: Kanban,
      title: "Project Management",
      subtitle: "Deliver Projects On Time, Every Time",
      description: "Visually track projects with Kanban boards, log and approve time with easy timesheet management, and track project budgets, expenses, and profitability with integrated project accounting.",
      keywords: ["Project management", "Kanban boards", "timesheet management", "project accounting"]
    },
    {
      icon: FileText,
      title: "Administration",
      subtitle: "Effortless Business Administration",
      description: "Track and manage company assets, store and manage contracts and agreements, and generate various operational and financial reports for better oversight.",
      keywords: ["Asset management", "contract management", "reporting"]
    },
    {
      icon: Calendar,
      title: "Performance Management and Appraisals",
      subtitle: "Drive Performance & Growth",
      description: "Implement a comprehensive appraisal module with organizational, departmental, and individual goals. Define performance bands and auto-classify using individual scoring for fair and objective evaluations.",
      keywords: ["Performance management", "employee appraisals", "goal setting"]
    }
  ];

  return (
    <div className="min-h-screen bg-background">
      <SEO 
        title="Workplaze Features - Complete Professional Services Management Suite"
        description="Discover Workplaze's comprehensive features: HRMS, CRM, Project Management, Resource Planning, Performance Management & more. Built for digital agencies."
        keywords="HRMS software, CRM for agencies, project management features, resource planning tools, performance management system, professional services software"
        structuredData={structuredData}
      />
      
      <Header />
      
      {/* Hero Section */}
      <section className="py-16 px-6 bg-gradient-to-br from-blue-50 to-indigo-100">
        <div className="container mx-auto max-w-4xl text-center">
          <h1 className="text-4xl font-bold mb-6">Powering Your Agency from Quote to Cash</h1>
          <p className="text-xl text-gray-600">
            Workplaze provides a comprehensive suite of modules designed to streamline every aspect of your professional services business.
          </p>
        </div>
      </section>

      {/* Core Features */}
      <section className="py-16 px-6">
        <div className="container mx-auto max-w-6xl">
          <div className="grid gap-12">
            {features.map((feature, index) => (
              <Card key={index} className="p-8">
                <div className="flex items-start space-x-6">
                  <feature.icon className="w-12 h-12 text-blue-600 mt-2" />
                  <div className="flex-1">
                    <CardHeader className="p-0 mb-4">
                      <CardTitle className="text-2xl mb-2">{feature.title}</CardTitle>
                      <CardDescription className="text-lg font-medium text-blue-600">
                        {feature.subtitle}
                      </CardDescription>
                    </CardHeader>
                    <CardContent className="p-0">
                      <p className="text-gray-600 mb-4">{feature.description}</p>
                      <div className="flex flex-wrap gap-2">
                        {feature.keywords.map((keyword, i) => (
                          <span key={i} className="px-3 py-1 bg-blue-100 text-blue-800 rounded-full text-sm">
                            {keyword}
                          </span>
                        ))}
                      </div>
                    </CardContent>
                  </div>
                </div>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* CXO Dashboard */}
      <section className="py-16 px-6 bg-gray-50">
        <div className="container mx-auto max-w-6xl">
          <Card className="p-8">
            <div className="flex items-start space-x-6">
              <TrendingUp className="w-12 h-12 text-purple-600 mt-2" />
              <div className="flex-1">
                <CardHeader className="p-0 mb-4">
                  <CardTitle className="text-2xl mb-2">CXO Dashboard</CardTitle>
                  <CardDescription className="text-lg font-medium text-purple-600">
                    Real-Time Insights for Strategic Decisions
                  </CardDescription>
                </CardHeader>
                <CardContent className="p-0">
                  <p className="text-gray-600 mb-4">
                    Select and track key performance indicators (KPIs) in real-time, providing CXOs with actionable intelligence for informed strategic decisions.
                  </p>
                  <div className="flex flex-wrap gap-2">
                    <span className="px-3 py-1 bg-purple-100 text-purple-800 rounded-full text-sm">CXO dashboard</span>
                    <span className="px-3 py-1 bg-purple-100 text-purple-800 rounded-full text-sm">real-time KPIs</span>
                    <span className="px-3 py-1 bg-purple-100 text-purple-800 rounded-full text-sm">business intelligence</span>
                  </div>
                </CardContent>
              </div>
            </div>
          </Card>
        </div>
      </section>

      {/* Enterprise Features */}
      <section className="py-16 px-6">
        <div className="container mx-auto max-w-6xl">
          <h2 className="text-3xl font-bold text-center mb-12">Enterprise-Grade Capabilities</h2>
          <div className="grid md:grid-cols-3 gap-8">
            <Card className="text-center p-6">
              <Shield className="w-12 h-12 mx-auto text-green-600 mb-4" />
              <CardHeader>
                <CardTitle>Built for Scale and Security</CardTitle>
              </CardHeader>
              <CardContent>
                <p>Robust enterprise features including Google/MS SSO, on-premise deployment options, and comprehensive audit trails.</p>
              </CardContent>
            </Card>
            
            <Card className="text-center p-6">
              <Brain className="w-12 h-12 mx-auto text-blue-600 mb-4" />
              <CardHeader>
                <CardTitle>AI-Powered Intelligence</CardTitle>
              </CardHeader>
              <CardContent>
                <p>Conversational interface for data insights. Ask questions to get instant answers about your organizational data.</p>
              </CardContent>
            </Card>
            
            <Card className="text-center p-6">
              <Globe className="w-12 h-12 mx-auto text-purple-600 mb-4" />
              <CardHeader>
                <CardTitle>Global Readiness</CardTitle>
              </CardHeader>
              <CardContent>
                <p>Supports multiple geographies, making it ideal for organizations with a global presence.</p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Integrations */}
      <section className="py-16 px-6 bg-gray-50">
        <div className="container mx-auto max-w-4xl text-center">
          <h2 className="text-3xl font-bold mb-6">Seamless Integrations</h2>
          <p className="text-xl text-gray-600 mb-8">
            Workplaze integrates seamlessly with other CRM, HRMS, Project Management, and Accounting systems. Even if you're already using other tools, Workplaze can unify your system of records. Plus, enjoy effortless time tracking via MS Teams and Slack integrations.
          </p>
          <div className="flex flex-wrap justify-center gap-4 mb-8">
            <span className="px-4 py-2 bg-blue-100 text-blue-800 rounded-full">CRM Integration</span>
            <span className="px-4 py-2 bg-blue-100 text-blue-800 rounded-full">HRMS Integration</span>
            <span className="px-4 py-2 bg-blue-100 text-blue-800 rounded-full">Accounting Integration</span>
            <span className="px-4 py-2 bg-blue-100 text-blue-800 rounded-full">Slack Integration</span>
            <span className="px-4 py-2 bg-blue-100 text-blue-800 rounded-full">MS Teams Integration</span>
          </div>
          <Link to="/integrations">
            <Button size="lg">Explore Integrations</Button>
          </Link>
        </div>
      </section>

      {/* CTA */}
      <section className="py-16 px-6 bg-blue-600 text-white">
        <div className="container mx-auto max-w-4xl text-center">
          <h2 className="text-3xl font-bold mb-6">Ready to Experience All Features?</h2>
          <p className="text-xl mb-8">See how Workplaze can transform your agency operations with a personalized demo.</p>
          <Link to="/request-demo">
            <Button size="lg" variant="secondary" className="text-lg px-8 py-3">
              Schedule Your Demo
            </Button>
          </Link>
        </div>
      </section>

      <Footer />
    </div>
  );
};

export default Features;
